@@ -12,6 +12,7 @@
 # under the License.
 
 import argparse
+import glob
 import os
 import re
 import six
@@ -32,13 +33,13 @@ def is_string(value):
 # list should contain only the alias name for the current branch.
 # This allows to avoid merging old templates versions aliases.
 valid_heat_template_versions = [
-  'rocky',
+  'wallaby',
 ]
 
 current_heat_template_version = valid_heat_template_versions[-1]
 
-required_params = ['EndpointMap', 'ServiceNetMap', 'DefaultPasswords',
-                   'RoleName', 'RoleParameters', 'ServiceData']
+required_params = ['EndpointMap', 'ServiceNetMap', 'RoleName',
+                   'RoleParameters', 'ServiceData']
 
 # NOTE(bnemec): The duplication in this list is intentional.  For the
 # transition to generated environments we have two copies of these files,
@@ -188,8 +189,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'server': ['description'],
     'servers': ['description'],
     'ExtraConfig': ['description'],
-    'DefaultPasswords': ['description',
-                         'default'],
     'BondInterfaceOvsOptions': ['description',
                                 'default',
                                 'constraints'],
@@ -329,6 +328,32 @@ def get_endpoint_map_from_env(filename):
     return None
 
 
+def compare_parameters(old_impl_path, new_impl_path):
+    old_impl_params = []
+    new_impl_params = []
+    for filename in glob.glob(old_impl_path + "/*.yaml"):
+        with open(filename, 'r') as f:
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            old_impl_params.extend(tpl["parameters"].keys())
+    for filename in glob.glob(new_impl_path + "/*.yaml"):
+        with open(filename, 'r') as f:
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+            new_impl_params.extend(tpl["parameters"].keys())
+    return set(old_impl_params).difference(set(new_impl_params))
+
+
+def compare_ceph_parameters(path):
+    old_path = base_path + "/deployment/ceph-ansible/"
+    new_path = base_path + "/deployment/cephadm/"
+    missing = compare_parameters(old_path, new_path)
+    if missing:
+        print("ERROR: Some parameters are missing in Ceph implementation at"
+              "'%s' compared to that in '%s' and they are: %s" %
+              (new_path, old_path, missing))
+        return 1
+    return 0
+
+
 def validate_endpoint_map(base_map, env_map):
     return sorted(base_map.keys()) == sorted(env_map.keys())
 
@@ -983,12 +1008,14 @@ def validate_service_hiera_interpol(f, tpl):
             # Omit if external deploy tasks in the path
             if 'external_deploy_tasks' in path:
                 continue
+            # Omit if deploy steps tasks in the path
+            if 'deploy_steps_tasks' in path:
+                continue
             # Omit apache remoteip proxy_ips
             if 'apache::mod::remoteip::proxy_ips' in path:
                 continue
             # Omit Designate rndc_allowed_addressses
-            if ('tripleo::profile::base::designate::rndc_allowed_addresses' in
-                    path):
+            if ('rndc_allowed_addresses' in path):
                 continue
             # Omit Neutron ml2 overlay_ip_version
             if 'neutron::plugins::ml2::overlay_ip_version' in path:
@@ -1366,11 +1393,15 @@ param_map = {}
 
 for base_path in path_args:
     if os.path.isdir(base_path):
+        exit_val |= compare_ceph_parameters(base_path)
         for subdir, dirs, files in os.walk(base_path):
             if '.tox' in dirs:
                 dirs.remove('.tox')
             for f in files:
                 file_path = os.path.join(subdir, f)
+                if 'tools/tests/nic_config_convert_samples' in file_path:
+                    continue
+
                 if 'environments/services-docker' in file_path:
                     print("ERROR: environments/services-docker should not be "
                           "used any more, use environments/services instead: "
